@@ -8,20 +8,20 @@ SORTED_GTF_FILENAME = 'sorted.gtf'
 COMBINED_FILENAME = 'combined.fa'
 INDEX_FILENAME = 'transcriptome.idx'
 WHITELIST_FILENAME = 'whitelist.txt'
-FILTER_WHITELIST_FILENAME = 'filter_whitelist.txt'
+FILTER_WHITELIST_FILENAME = 'filter_barcodes.txt'
 INSPECT_FILENAME = 'inspect.json'
 
 BUS_FILENAME = 'output.bus'
 BUS_S_FILENAME = 'output.s.bus'
 BUS_SC_FILENAME = 'output.s.c.bus'
-BUS_SCS_FILENAME = 'output.s.c.s.bus'
+BUS_UNFILTERED_FILENAME = 'output.unfiltered.bus'
+BUS_FILTERED_FILENAME = 'output.filtered.bus'
 BUS_CDNA_PREFIX = 'spliced'
 BUS_INTRON_PREFIX = 'unspliced'
 ECMAP_FILENAME = 'matrix.ec'
 TXNAMES_FILENAME = 'transcripts.txt'
-COUNTS_DIR = 'counts'
 COUNTS_PREFIX = 'cells_x_genes'
 ADATA_PREFIX = 'adata'
 
-FILTERED_DIR = 'filtered'
-UNFILTERED_DIR = 'unfiltered'
+UNFILTERED_COUNTS_DIR = 'counts_unfiltered'
+FILTERED_COUNTS_DIR = 'counts_filtered'
